from django.contrib.gis import admin
from django.contrib.gis.maps.google import GoogleMap
from models import *
from django.conf import settings

class ImageInline(admin.TabularInline):
  model = Image
  extra = 5

class VideoInline(admin.TabularInline):
  model = Video
  extra = 3

class AudioInline(admin.TabularInline):
  model = Audio
  extra = 2

class TextInline(admin.TabularInline):
  model = Text
  extra = 4

class FlyoverAdmin(admin.OSMGeoAdmin):
  fieldsets = (
    ('Flyover Data', {'fields': (('point','name', 'txt',)), 'classes': ('show','extrapretty')}),
  )
  map_template = 'gis/admin/google.html'
  default_lon = 72.855211097628413
  default_lat = 19.415775291486027
  default_zoom = 4
  extra_js = ['http://openstreetmap.org/openlayers/OpenStreetMap.js', 'http://maps.google.com/maps?file=api&amp;v=2&amp;key=%s' % settings.GOOGLE_MAPS_API_KEY]
  inlines = [ImageInline, VideoInline, AudioInline, TextInline] 

admin.site.register(Flyover, FlyoverAdmin)
admin.site.register(Image)
admin.site.register(ImageCategory)
admin.site.register(Video)
admin.site.register(VideoCategory)
admin.site.register(Audio)
admin.site.register(AudioCategory)
admin.site.register(Text)
admin.site.register(TextCategory)

